@@ -585,34 +585,40 @@ class GetFirstLetter(object):
             s2_list.append(''.join(charLst))
         return '_'.join(s2_list)
 
-class Open:
+class Cpen:
     """
     无论文件是否存在都写入文件，功能待完善
     """
-    def __init__(self, path, data, mode, encoding='utf-8'):
+    def __init__(self, path, mode, encoding='utf-8'):
         self.path = path
-        self.data = data
         self.mode = mode
         if not os.path.exists(path):
             with open(file=path, mode='w', encoding=encoding):
                 pass
-            self.file_handle = open(file=path, mode=mode, encoding=encoding)
+            self.f = open(file=path, mode=mode, encoding=encoding)
         else:
-            self.file_handle = open(file=path, mode=mode, encoding=encoding)
+            self.f = open(file=path, mode=mode, encoding=encoding)
 
     def __enter__(self):
-        return self.file_handle
+        return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self.file_handle.close()
+        self.f.close()
 
     def readline(self):
         while True:
-            line = self.file_handle.readline()
+            line = self.f.readline()
             if not line:
                 break
             yield line
 
+    def readlines(self, num_lines=10000):
+        while True:
+            lines = self.f.readlines(num_lines)
+            if not lines:
+                break
+            yield lines
+
 
 if __name__=='__main__':
     print(Timer.datebetween('2022-01-01 00:00:00', '2022-01-04 00:00:00'))
